@@ -83,3 +83,23 @@ def test_find_bitbake_env():
     assert find_bitbake_env(path, "DL_DIR")
     with pytest.raises(AssertionError):
         assert find_bitbake_env(path, "DUMMY_VAR")
+
+
+def test_handle_log(capsys, oebuild_git_object):
+
+    from tuxbake.utils import handle_log, git_init
+
+    logs_list = ["test", b"test-check-out", b"test-check-err"]
+    handle_log(logs_list)
+    out, err = capsys.readouterr()
+    assert "test-check-err" in err
+
+    with capsys.disabled():
+        oebuild_object = oebuild_git_object[0]
+        src_dir = oebuild_object.src_dir
+        git_init(oebuild_object, src_dir)
+
+        assert os.path.exists(f"{src_dir}/fetch.log")
+        with open(f"{src_dir}/fetch.log") as f:
+            data = f.readline()
+            assert "INFO - Running cmd:" in data
